#!/bin/bash
# This script will install PSU12-Sritrang on your existing ubuntu server
# update by pom 10-May-2016 
# update by wiboon 18-May-2016 20-Jun-2016 
#                  14-Mar-2018 4-Apr-2018 18-Apr-2018 20-Apr-2018 23-Apr-2018 31-May-2018
#                  13-Jun-2018 22-Jun-2018 14-Aug-2018 28-Aug-2018 30-Oct-2019
# update by wiboon 22-May-2020

if ! [ "${HOME}" = "/root" ]; then
  echo 'Please run command "sudo su -" for set HOME to /root'
  exit 
fi

#--Check user confirmation before installation--
while true; do
    echo "This script will install PSU12-Sritrang on your existing ubuntu server (16.04.x or higher)"
    read -p "Confirm to start installation? (y/n)" yn
    case $yn in
        [Yy]* ) CONFIRM_INSTALL="yes"; break;;
        [Nn]* ) CONFIRM_INSTALL="no"; break;;
        * ) echo "Please answer y or n.";;
    esac
done
if [ "${CONFIRM_INSTALL}" = "no" ]; then
  exit 
fi

#--Setting some variables
start1=$(date)
DIR1=${PWD}

#--Update ubuntu packages--
apt-get update && apt-get -y dist-upgrade
apt-get -y autoremove

#--Install new packages--
#
#utitlity packages
apt-get -y install curl dialog expect whois nbtscan netmask nmap imagemagick unzip wakeonlan lynx w3m

#cloning packages
apt-get -y install udpcast
apt-get -y install partclone

#pxeboot via tftpd
apt-get -y install tftpd-hpa tftp

#apache web server
apt-get -y install apache2 apache2-doc libapache2-mod-perl2

#splash images
apt-get -y install grub2-splashimages

#php
codename=$(lsb_release -c | awk '{print $2}')
if [ "${codename}" = "focal" ]; then
  apt-get -y install php7.4
  apt-get -y install libapache2-mod-php7.4
fi
if [ "${codename}" = "bionic" ]; then
  apt-get -y install php7.2
  apt-get -y install libapache2-mod-php7.2
fi
if [ "${codename}" = "xenial" ]; then
  apt-get -y install php7.0
  apt-get -y install libapache2-mod-php7.0
fi

#vsftpd
apt-get -y install vsftpd

#nfs
apt-get -y install portmap nfs-kernel-server

#POP3 mail
apt-get -y install dovecot-common dovecot-pop3d

#host firewall
apt-get -y install shorewall
cp -p /usr/share/doc/shorewall/examples/one-interface/zones /etc/shorewall
cp -p /usr/share/doc/shorewall/examples/one-interface/interfaces /etc/shorewall
cp -p /usr/share/doc/shorewall/examples/one-interface/policy /etc/shorewall
cp -p /usr/share/doc/shorewall/examples/one-interface/rules /etc/shorewall

#dhcp server
apt-get -y install isc-dhcp-server

#utility report dhcp IP leases
wget -P /tmp http://ftp.psu.ac.th/pub/omar/reportdhcp.pl-2.1.tar.gz
tar -zxvf /tmp/reportdhcp.pl-2.1.tar.gz -C /usr/lib/cgi-bin
# config file for reportdhcp
cp -p ${DIR1}/reportdhcp.pl  /usr/lib/cgi-bin
chmod +x /usr/lib/cgi-bin/reportdhcp.pl

#get mac-ip from local network
#mkdir -p /var/www/log
#mkdir -p ${HOME}/mac-ip
#wget -P ${HOME}/mac-ip http://ftp.psu.ac.th/pub/psu-12/dists-12/home/mama/mac-ip/get-localnet.sh
#wget -P ${HOME}/mac-ip http://ftp.psu.ac.th/pub/psu-12/dists-12/home/mama/mac-ip/myhour.sh
#wget -P /etc/cron.d http://ftp.psu.ac.th/pub/psu-12/dists-12/etc/cron.d/myhour

#Install MRTG using PSU Installer psu-mrtg
#wget http://ftp.psu.ac.th/pub/psu-mrtg/psu-mrtg.tgz -N -P /tmp 
#tar -zxpvf /tmp/psu-mrtg.tgz -C /tmp 
#cd /tmp/psu-mrtg
#sh install-psu-mrtg.sh -n

#Install FreeRADIUS using PSU Installer psu-radius
wget http://ftp.psu.ac.th/pub/psu-radius/psu-radius.tgz -N -P /tmp 
tar -zxpvf /tmp/psu-radius.tgz -C /tmp 
cd /tmp/psu-radius 
sh install-psu-radius.sh -n

#Install Windows user login log using PSU Installer psu-ticker
wget http://ftp.psu.ac.th/pub/psu-ticker/psu-ticker.tgz -N -P /tmp 
tar -zxpvf /tmp/psu-ticker.tgz -C /tmp 
cd /tmp/psu-ticker 
sh install-psu-ticker.sh -n

#--Configuration Section--
#
#config apache2 
file1000=/etc/apache2/sites-available/000-default.conf
cp -p $file1000 $file1000.$(date +%F-%H%M%S)
sed -i '/DocumentRoot/ c DocumentRoot /var/www' $file1000
cp -p /etc/apache2/conf-available/serve-cgi-bin.conf /etc/apache2/conf-available/serve-cgi-bin.conf.$(date +%F-%H%M%S)
cp -p ${DIR1}/serve-cgi-bin.conf      /etc/apache2/conf-available
echo "Servername localhost"    >>  /etc/apache2/apache2.conf
echo "AddDefaultCharset UTF-8" >>  /etc/apache2/conf-available/charset.conf
a2enmod cgi

#download PSU12-Sritrang all scripts from ftp server to a local temporary directory
DIR2=${DIR1}/scripts
wget -r -N -l1 -nd -A* ftp.psu.ac.th/pub/psu12-sritrang/download/scripts -P ${DIR2}
rm ${DIR2}/index.htm*
rm ${DIR2}/*.gif

#config tftp directories
mkdir -p /var/lib/tftpboot/sysresccd
mkdir -p /var/lib/tftpboot/linuxmint
mkdir -p /var/lib/tftpboot/psulib
mkdir -p /var/lib/tftpboot/custom
mkdir -p /var/lib/tftpboot/boot
mkdir -p /var/lib/tftpboot/pxelinux.cfg

#config sysresccd Live CD
VERSION2=5.1.2
wget http://ftp.psu.ac.th/pub/sysresccd/systemrescuecd-x86-${VERSION2}.iso -P /tmp
mkdir /tmp/sysresccd
mount -o loop /tmp/systemrescuecd-x86-${VERSION2}.iso /tmp/sysresccd
cp -v /tmp/sysresccd/isolinux/pxelinux.0 /var/lib/tftpboot/
cp -v /tmp/sysresccd/sysrcd* /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/initram.igz /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/chain.c32 /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/menu.c32 /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/memdisk /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/rescue32 /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/rescue64 /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/ifcpu64.c32 /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/isolinux/vesamenu.c32 /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/bootdisk/freedos.img /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/bootdisk/hdt.img /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/bootdisk/mhdd.img /var/lib/tftpboot/sysresccd/
cp -v /tmp/sysresccd/bootdisk/memtestp /var/lib/tftpboot/sysresccd/
umount /tmp/sysresccd 

#config sysresccd for PXE boot autorun
mkdir -p /var/www/sysresccd
ln -svf /var/lib/tftpboot/sysresccd/sysrcd.* /var/www/sysresccd/
cp -p ${DIR2}/autorun*               /var/www/sysresccd/

#config /root files (HOME is /root after command "sudo su -")
LISTSHELL="install-grub2.sh install-grub2-18.04.sh install-grub2-uefi-gpt.sh makezone.sh backup-server.sh change-mtu.sh"
for H in ${LISTSHELL}
do
	cp -p ${DIR2}/${H} ${HOME}
done
cp -rp ${DIR2}                     ${HOME}	
cp -p  ${DIR2}/startroot.sh        ${HOME}
cp -p  ${DIR2}/easy-config.sh      ${HOME}
ln -s  ${HOME}/scripts/mainmenu.sh  ${HOME}/mainmenu.sh

#make autostart script
cp -p ${DIR1}/.bash_login_root     ${HOME}/.bash_login 

#make directory backuppxezone
cp -rp ${DIR1}/backuppxezone ${HOME}
cp -rp ${DIR1}/backupzone    ${HOME}

#config PXE boot menu zone1
cp -p ${DIR1}/backuppxezone/penguinpom.jpg  /var/lib/tftpboot/sysresccd/psu-12.jpg
cp -p ${DIR1}/backuppxezone/pxelinux.cfg.master/default /var/lib/tftpboot/pxelinux.cfg/
if [ "${codename}" == "trusty" -o "${codename}" == "xenial" ]; then
  cp -rp ${DIR1}/backupzone/zone1 /var/lib/tftpboot/
else
  cp -rp ${DIR1}/backupzone/zone1 /var/lib/tftpboot/
  cp -p ${DIR1}/zone1extra/*.mnu /var/lib/tftpboot/zone1/
  cp -p ${DIR1}/zone1extra/*.mnu ${HOME}/backupzone/zone1/
fi

#config user papa, prnews and sendfile
#
useradd -m -s /bin/bash papa
echo
echo "Added user name papa"
cond="true"
while ${cond}; do
echo "Please input password for user name papa (example: papa123)"
passwd papa
if [ $? -eq 0 ]; then
  echo password OK
  cond="false"
fi
done
#
useradd -m -s /bin/bash prnews
echo
echo "Added user name prnews"
cond="true"
while ${cond}; do
echo "Please input password for user name prnews (example: 123456)"
passwd prnews
if [ $? -eq 0 ]; then
  echo password OK
  cond="false"
fi
done
#
useradd -m -s /bin/bash sendfile
echo
echo "Added user name sendfile"
cond="true"
while ${cond}; do
echo "Please input password for user name sendfile (example: 123456)"
passwd sendfile
if [ $? -eq 0 ]; then
  echo password OK
  cond="false"
fi
done
#

#config /home/papa
wget -r -N -l1 -nd -A* ftp.psu.ac.th/pub/psu12-sritrang/download/scripts/papa -P /home/papa
rm /home/papa/index.htm*
rm /home/papa/*.gif
rm /home/papa/papa
mkdir -p /home/papa/swap-area 
echo "bash mystart.sh" >  /home/papa/.bash_login
echo "logout"          >> /home/papa/.bash_login

#config cloning directories
mkdir -p /var/www/cloning
mkdir -p /var/www/cloning/zone1

#config cloning scripts
cp -p ${DIR2}/welcome.sh            /var/www/cloning
cp -p ${DIR2}/backup.sh             /var/www/cloning
cp -p ${DIR2}/menubackuprestore.sh  /var/www/cloning

#config directories permission for user papa
chown -Rv papa:papa		 /home/papa
chown -Rv papa:papa		 /var/lib/tftpboot/*
chown -Rv papa:papa		 /var/www/cloning
chown -Rv papa:papa		 /var/www/sysresccd

#config /home/prnews and image while server booting
wget http://ftp.psu.ac.th/pub/psu-installer/install-psu12-sritrang/psu12-sritrang-installer.jpg -P /tmp
convert -resize 640x480 /tmp/psu12-sritrang-installer.jpg /viewpsu12.jpg
cp -p ${DIR1}/picture/*             /home/prnews
chown -Rv prnews  	         /home/prnews 

#config web server home page and put some files in directory /var/www
cp -p  ${DIR1}/index.php.var   	 /var/www/index.php
cp -rp ${DIR1}/reportdhcp      	 /var/www
cp -p ${DIR1}/mrtg/index.php  	 /var/www/mrtg
ln -s /etc/dhcp/dhcpd.conf    	 /var/www/dhcpd.txt
ln -s /home/prnews    	         /var/www/
cp -rp ${DIR1}/test              /var/www 
chown -R root:root /var/www/test
chown -R www-data /var/www/test/report
chmod 777 /var/www/test/report/*.html
chmod 777 /var/www/test/report/*.txt
chown -R www-data /var/www/test/wakeonlan
cp -p ${DIR1}/printlabelipmac/*  /var/www 
touch /var/www/printlabelipmac.html
chown www-data /var/www/printlabelipmac.html

#config freeradius file for backup clients.conf
freeradiusversion=$(freeradius -v | grep -i version | head -1 | awk '{print $4}' | cut -d. -f1,2)
case ${freeradiusversion} in
3.?)
  #3.x 
  echo "freeradius version is ${freeradiusversion}"
  echo "path is /etc/freeradius/${freeradiusversion}/"
  cp -p /etc/freeradius/${freeradiusversion}/clients.conf    /etc/freeradius/${freeradiusversion}/clients.conf.master
  ;;
2.?)
  #2.x
  echo "freeradius version is ${freeradiusversion}"
  echo "path is /etc/freeradius/"
  cp -p /etc/freeradius/clients.conf    /etc/freeradius/clients.conf.master
  ;;
*)
  #3.x up
  echo "freeradius version is ${freeradiusversion}"
  echo "path is /etc/freeradius/${freeradiusversion}/"
  cp -p /etc/freeradius/${freeradiusversion}/clients.conf    /etc/freeradius/${freeradiusversion}/clients.conf.master
  ;;
esac

#config ubuntu source list for changesourceslist.sh
cp -p /etc/apt/sources.list           /etc/apt/sources.list.th.archive.ubuntu.com

#config system configuration files
#
#backup existing file then copy our custom file
LIST="/etc/profile /etc/ssh/sshd_config /etc/default/nfs-kernel-server /etc/default/nfs-common /etc/exports /etc/dovecot/dovecot.conf /etc/default/isc-dhcp-server /etc/vsftpd.conf /etc/network/interfaces"
for I in $LIST
do
	cp -p ${I} ${I}.org
	cp -p ${DIR1}/${codename}/$(basename "${I}") ${I}
done

#config custom network configuration
cp -p ${DIR1}/interface*                 /etc/network
cp -p ${DIR1}/dhcp*                      /etc/dhcp
if [ "${codename}" == "trusty" -o "${codename}" == "xenial" ]; then
  sed -i '/start on runlevel/ s/^/#/g'  /etc/init/isc-dhcp-server.conf
fi

#config boot grub
#cp /etc/default/grub  /etc/default/grub.org
#cp ${DIR1}/grub       /etc/default
#update-grub
cp -p /etc/default/grub  /etc/default/grub.org
if [ "${codename}" = "focal" ]; then
  # use ifupdown package instead of new netplan
  apt-get -y install ifupdown resolvconf
  apt-get -y install net-tools
  echo 'GRUB_CMDLINE_LINUX="net.ifnames=0 netcfg/do_not_use_netplan=true"' >> /etc/default/grub
fi
if [ "${codename}" = "bionic" ]; then
  # use ifupdown package instead of new netplan
  apt-get -y install ifupdown resolvconf
  apt-get -y install net-tools
  echo 'GRUB_CMDLINE_LINUX="net.ifnames=0 netcfg/do_not_use_netplan=true"' >> /etc/default/grub
fi
if [ "${codename}" = "xenial" ]; then
  echo 'GRUB_CMDLINE_LINUX_DEFAULT="net.ifnames=0"' >> /etc/default/grub
fi
#if [ "${codename}" = "trusty" ]; then
#  echo 'GRUB_CMDLINE_LINUX_DEFAULT="net.ifnames=1 biosdevname=0"' >> /etc/default/grub
#fi
echo 'GRUB_BACKGROUND="/viewpsu12.jpg"' >> /etc/default/grub
update-grub

#--Copy startup script for priviledge user account--
cd ${DIR1}
user99=$(grep "1000:.*/home" /etc/passwd | cut -d: -f1)
cp -p ${DIR2}/startmama.sh      /home/${user99}
cp -p ${DIR1}/.bash_login_mama  /home/${user99}/.bash_login
chown ${user99}:${user99}    /home/${user99}/.bash_login

#--End of installation--

echo "-------------------------------------------------"
echo "Start time: " $start1
echo "Finished time: " $(date)
echo "-------------------------------------------------"
echo "Install PSU12-Sritrang completed. Thank you. "
echo "-------------------------------------------------"
bash ${DIR2}/countdown2.sh
#End.
